@@ -11,11 +11,14 @@ import sys
 from .lib import TestBigRepoRW
 from git import Commit
 from gitdb import IStream
-from git.compat import xrange
-from git.test.test_commit import assert_commit_serialization
+from git.test.test_commit import TestCommitSerialization
 
 
-class TestPerformance(TestBigRepoRW):
+class TestPerformance(TestBigRepoRW, TestCommitSerialization):
+
+    def tearDown(self):
+        import gc
+        gc.collect()
 
     # ref with about 100 commits in its history
     ref_100 = '0.1.6'
@@ -48,7 +51,7 @@ class TestPerformance(TestBigRepoRW):
             # END for each object
         # END for each commit
         elapsed_time = time() - st
-        print("Traversed %i Trees and a total of %i unchached objects in %s [s] ( %f objs/s )"
+        print("Traversed %i Trees and a total of %i uncached objects in %s [s] ( %f objs/s )"
               % (nc, no, elapsed_time, no / elapsed_time), file=sys.stderr)
 
     def test_commit_traversal(self):
@@ -76,7 +79,7 @@ class TestPerformance(TestBigRepoRW):
               % (nc, elapsed_time, nc / elapsed_time), file=sys.stderr)
 
     def test_commit_serialization(self):
-        assert_commit_serialization(self.gitrwrepo, self.gitrwrepo.head, True)
+        self.assert_commit_serialization(self.gitrwrepo, '58c78e6', True)
 
         rwrepo = self.gitrwrepo
         make_object = rwrepo.odb.store
@@ -86,7 +89,7 @@ class TestPerformance(TestBigRepoRW):
 
         nc = 5000
         st = time()
-        for i in xrange(nc):
+        for i in range(nc):
             cm = Commit(rwrepo, Commit.NULL_BIN_SHA, hc.tree,
                         hc.author, hc.authored_date, hc.author_tz_offset,
                         hc.committer, hc.committed_date, hc.committer_tz_offset,
